/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#include "OssMessageBoxes.hpp"

using namespace openstreetsound::tools;

OssMessageBoxes::OssMessageBoxes() {

}

OssMessageBoxes::~OssMessageBoxes() {

}

void OssMessageBoxes::createWindowFailed() {
	MessageBox(NULL, L"Call to CreateWindow failed!",
		L"OpenStreetSounds Fatal Error!", NULL);
}

void OssMessageBoxes::downloadXMLComplete(HWND hWnd) {
	MessageBox(hWnd, L"Download and filtering complete!",
		L"Open Street Sounds XML Download and Filteringt", MB_ICONINFORMATION);
}

int OssMessageBoxes::checkXMLFailed(HWND hWnd) {
	return MessageBox(hWnd, L"Cannot find the filtered osm xml file\n"
		L"\"filtered.osm\" located in the \"res\" - folder.\n"
		L"Press Ok to download it now (~50mb) or Cancel to close the application!"
		, L"Open Street Sounds Error!", MB_OKCANCEL | MB_ICONWARNING);
}

void OssMessageBoxes::downloadTilesFailed(HWND hWnd) {
	MessageBox(hWnd, L"An error occured while downloading one or more tiles\n"
		L"Please change the tileserver and try refreshing the map ('F5')\n"
		, L"Open Street Sounds Error!", MB_ICONINFORMATION);
}

void OssMessageBoxes::about(HWND hWnd) {
	MessageBox(hWnd, L"Open Street Sound\n\nBachelors project\n"
		L"by Michael Macek - 0504524\n"
		L"e0504524@student.tuwien.ac.at\n"
		L"Vienna University of Technology - TU Wien",
		L"Open Street Sounds About", MB_ICONINFORMATION);
}

void OssMessageBoxes::help(HWND hWnd) {
	MessageBox(hWnd, L"Controls:\n\n"
		L"Mouse drag...\tmove map\n"
		L"Left click...\tset marker\n"
		L"Right click...\tremove marker and stop sound\n"
		L"Mouse scroll...\tzoom\n"
		L"F1 & Home...\tset view to POIs\n"
		L"F5...\t\trefresh map\n"
		, L"Open Street Sounds Help", MB_ICONINFORMATION);
}

int OssMessageBoxes::downloadXMLRequest(HWND hWnd) {
	return MessageBox(hWnd, L"Are you sure,"
		L"you want to download and filter a new XML file? \n"
		L"This might take a while... (~50mb)",
		L"Open Street Sounds XML Download and Filtering", MB_ICONQUESTION | MB_OKCANCEL);
}

void OssMessageBoxes::soundLoadingFailed(HWND hWnd, int error) {
	std::wstring msg = L"Playback of the sounds failed!\nError: " + std::to_wstring(error);
	MessageBox(hWnd, msg.c_str(),
		L"Open Street Sounds Error!", MB_ICONINFORMATION);
}

void OssMessageBoxes::showLicense(HWND hWnd) {
	MessageBox(hWnd, L"This program is free software: you can redistribute it and/or modify\n"
		L"it under the terms of the GNU General Public License as published by\n"
		L"the Free Software Foundation, either version 3 of the License, or\n"
		L"(at your option) any later version.\n"
		L"\n"
		L"This program is distributed in the hope that it will be useful,\n"
		L"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
		L"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
		L"GNU General Public License for more details.\n"
		L"\n"
		L"You should have received a copy of the GNU General Public License\n"
		L"along with this program.  If not, see <http://www.gnu.org/licenses/>.\n",
		L"Open Street Sounds License", MB_ICONINFORMATION);
}

int OssMessageBoxes::bulkDownloadTiles(HWND hWnd) {
	return MessageBox(hWnd, L"Are you sure, you want to download all the missing tiles? \n"
		L"This might take a while... (up to an hour!)",
		L"Open Street Sounds bulk tile downloading", MB_ICONQUESTION | MB_OKCANCEL);
}

void OssMessageBoxes::bulkDownloadFinsihed(HWND hWnd, double time, int tiles) {
	std::wstring stats = L"It took " + std::to_wstring(time/60) + L" minutes to download " + std::to_wstring(tiles) + L" tile(s)!";
	MessageBox(hWnd, stats.c_str(),
		L"Open Street Sounds bulk tile downloading", MB_ICONINFORMATION);
}

