/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef OSSXMLLOADER_HPP_
#define OSSXMLLOADER_HPP_

#include <string>
#include <stdio.h>
#include <fstream>
#include <curl/curl.h>
#include <curl/easy.h>

namespace openstreetsound {
	namespace tools {
		namespace data {
			/*
			Class OssXmlLoader
			 
			used to download and filter the osm xml file
			*/
			class OssXmlLoader {
			public:
				/*
				Constructor
				 
				initializes the server to the Overpass Api url
				*/
				OssXmlLoader();

				/*
				Decontructor
				*/
				~OssXmlLoader();

				/*
				downfload()
				
				downloads a osm xml file with libcurl
				which is created by the overpass api by sending a query
				and saves it as "downloaded.osm" into the "res" folder
				*/
				void download();

				/*
				filter()
				
				filters the downloaded.osm file
				with the external program osmfilter.exe
				which is using the parameters from the file dl_parameters.txt
				*/
				void filter();

				/*
				cleanup()
				
				deletes the previously downloaded file "downloaded.osm"
				*/
				void cleanup();

			private:
				/*
				std::string readQuery()
				
				Resturns: the content of the file overpass_api_query.txt
				reads the file and stores it into a std::string which is used
				in the download() method
				*/
				std::string readQuery();

				/*
				std::string server
				
				holds the server url of the overpass api
				*/
				std::string server;

			};
		}
	}
}
#endif