/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#include "OssPin.hpp"

using namespace openstreetsound::tools::visual;

/* constructor */
OssPin::OssPin() {
	sizeX = 25;
	sizeY = 25;
	offsetX = -(sizeX/2);
	offsetY = -sizeY;
	location = OssPoint();
	visible = false;
	pIco = (HICON)LoadImage(NULL, TEXT("res/pin.ico"), IMAGE_ICON, 0, 0, LR_LOADFROMFILE );
	longitude = 0;
	latitude = 0;
}

void OssPin::draw(HDC hdc) {
	DrawIconEx(hdc, location.getX()+offsetX, location.getY()+offsetY, pIco, sizeX, sizeY, 0, NULL, DI_NORMAL );
}

void OssPin::setLocation(int x, int y) {
	location = OssPoint(x,y);
}

OssPoint OssPin::getLocation() {
	return location;
}

void OssPin::setLongLat(double lo, double la) {
	longitude = lo;
	latitude = la;
}

std::pair<double, double> OssPin::getLongLat() {
	return std::make_pair(longitude, latitude);
}

double OssPin::getLongitude() {
	return longitude;
}

double OssPin::getLatitude() {
	return latitude;
}

void OssPin::moveLocation(const OssPoint &p){
	location += p;
}

void OssPin::setVisible() {
	visible = true;
}

void OssPin::setInvisible() {
	visible = false;
}

bool OssPin::getVisibility() {
	return visible;
}

OssPin::~OssPin() {
	DeleteObject(pIco);
}